@@ -1,6 +1,9 @@
+#define NO_IMPORT_PYGOBJECT
+
 #include <pygobject.h>
 
 void empathy_register_classes (PyObject *d); 
+void empathy_add_constants(PyObject *module, const gchar *strip_prefix);
 DL_EXPORT(void) initempathy(void);
 extern PyMethodDef empathy_functions[];
 
@@ -15,6 +18,7 @@ initempathy(void)
 	d = PyModule_GetDict (m);
 	
 	empathy_register_classes (d);
+	empathy_add_constants(m, "EMPATHY_");
 	
 	if (PyErr_Occurred ()) {
 		PyErr_Print();
