@@ -302,11 +302,19 @@ account_dialog_create_settings_widget (EmpathyAccountsDialog *dialog,
 
   icon_name = empathy_account_settings_get_icon_name (settings);
 
+  if (!gtk_icon_theme_has_icon (gtk_icon_theme_get_default (),
+          icon_name))
+    /* show the default icon; keep this in sync with the default
+     * one in empathy-accounts-dialog.ui.
+     */
+    icon_name = GTK_STOCK_CUT;
+
   gtk_image_set_from_icon_name (GTK_IMAGE (priv->image_type),
       icon_name, GTK_ICON_SIZE_DIALOG);
   gtk_widget_set_tooltip_text (priv->image_type,
       empathy_protocol_name_to_display_name
       (empathy_account_settings_get_protocol (settings)));
+  gtk_widget_show (priv->image_type);
 
   accounts_dialog_update_name_label (dialog,
       empathy_account_settings_get_display_name (settings));
@@ -385,6 +393,7 @@ accounts_dialog_protocol_changed_cb (GtkWidget *widget,
       return;
     }
 
+#ifndef HAVE_NBTK
   if (tp_connection_manager_protocol_can_register (proto) && !is_gtalk)
     {
       gtk_widget_show (priv->radiobutton_register);
@@ -395,6 +404,11 @@ accounts_dialog_protocol_changed_cb (GtkWidget *widget,
       gtk_widget_hide (priv->radiobutton_register);
       gtk_widget_hide (priv->radiobutton_reuse);
     }
+#else
+  gtk_widget_hide (priv->radiobutton_register);
+  gtk_widget_hide (priv->radiobutton_reuse);
+#endif
+
   g_object_unref (cm);
 }
 
@@ -784,16 +798,26 @@ accounts_dialog_view_delete_activated_cb (EmpathyCellRendererActivatable *cell,
     }
 
   question_dialog_primary_text = g_strdup_printf (
+#ifndef HAVE_NBTK
       _("You are about to remove your %s account!\n"
           "Are you sure you want to proceed?"),
+#else
+      /* Translators: this is used only when built on a moblin platform */
+      _("Do you want to remove %s from your computer?"),
+#endif /* HAVE_NBTK */
       empathy_account_get_display_name (account));
 
   accounts_dialog_show_question_dialog (dialog, question_dialog_primary_text,
+#ifndef HAVE_NBTK
       _("Any associated conversations and chat rooms will NOT be "
           "removed if you decide to proceed.\n"
           "\n"
           "Should you decide to add the account back at a later time, "
           "they will still be available."),
+#else
+      /* Translators: this is used only when built on a moblin platform */
+      _("This will not remove your account on the server."),
+#endif /* HAVE_NBTK */
       G_CALLBACK (accounts_dialog_delete_account_response_cb),
       dialog,
       GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
@@ -832,6 +856,9 @@ accounts_dialog_model_add_columns (EmpathyAccountsDialog *dialog)
       accounts_dialog_model_pixbuf_data_func,
       dialog,
       NULL);
+#ifdef HAVE_NBTK
+  g_object_set (cell, "ypad", 4, NULL);
+#endif
 
   /* Name renderer */
   cell = gtk_cell_renderer_text_new ();
@@ -854,6 +881,9 @@ accounts_dialog_model_add_columns (EmpathyAccountsDialog *dialog)
   gtk_tree_view_column_pack_start (column, cell, FALSE);
   g_object_set (cell,
         "icon-name", GTK_STOCK_DELETE,
+#ifdef HAVE_NBTK
+        "show-on-select", TRUE,
+#endif
         NULL);
 
   g_signal_connect (cell, "path-activated",
@@ -1402,6 +1432,7 @@ accounts_dialog_button_create_clicked_cb (GtkWidget *button,
 
   g_free (str);
 
+#ifndef HAVE_NBTK
   if (tp_connection_manager_protocol_can_register (proto))
     {
       gboolean active;
@@ -1411,6 +1442,7 @@ accounts_dialog_button_create_clicked_cb (GtkWidget *button,
       if (active)
         empathy_account_settings_set_boolean (settings, "register", TRUE);
     }
+#endif
 
   if (is_gtalk)
     empathy_account_settings_set_icon_name_async (settings, "im-google-talk",
@@ -1538,12 +1570,68 @@ accounts_dialog_cms_ready_cb (EmpathyConnectionManagers *cms,
     }
 }
 
+static void
+accounts_dialog_accounts_setup (EmpathyAccountsDialog *dialog)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
+  GList *accounts, *l;
+
+  g_signal_connect (priv->account_manager, "account-created",
+      G_CALLBACK (accounts_dialog_account_added_cb),
+      dialog);
+  g_signal_connect (priv->account_manager, "account-deleted",
+      G_CALLBACK (accounts_dialog_account_removed_cb),
+      dialog);
+  g_signal_connect (priv->account_manager, "account-enabled",
+      G_CALLBACK (accounts_dialog_account_enabled_cb),
+      dialog);
+  g_signal_connect (priv->account_manager, "account-disabled",
+      G_CALLBACK (accounts_dialog_account_disabled_cb),
+      dialog);
+  g_signal_connect (priv->account_manager, "account-changed",
+      G_CALLBACK (accounts_dialog_account_changed_cb),
+      dialog);
+  g_signal_connect (priv->account_manager, "account-connection-changed",
+      G_CALLBACK (accounts_dialog_connection_changed_cb),
+      dialog);
+
+  /* Add existing accounts */
+  accounts = empathy_account_manager_dup_accounts (priv->account_manager);
+  for (l = accounts; l; l = l->next)
+    {
+      accounts_dialog_add_account (dialog, l->data);
+      g_object_unref (l->data);
+    }
+  g_list_free (accounts);
+
+  priv->cms = empathy_connection_managers_dup_singleton ();
+  if (!empathy_connection_managers_is_ready (priv->cms))
+    g_signal_connect (priv->cms, "notify::ready",
+        G_CALLBACK (accounts_dialog_cms_ready_cb), dialog);
+
+  accounts_dialog_model_select_first (dialog);
+}
+
+static void
+accounts_dialog_manager_ready_cb (EmpathyAccountManager *manager,
+    GParamSpec *pspec,
+    gpointer user_data)
+{
+  if (!empathy_account_manager_is_ready (manager))
+    return;
+
+  accounts_dialog_accounts_setup (user_data);
+}
+
 static void
 accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
 {
   GtkBuilder                   *gui;
   gchar                        *filename;
   EmpathyAccountsDialogPriv    *priv = GET_PRIV (dialog);
+#ifdef HAVE_NBTK
+  GtkWidget                    *action_area;
+#endif
 
   filename = empathy_file_lookup ("empathy-accounts-dialog.ui", "src");
 
@@ -1577,6 +1665,15 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
 
   g_object_unref (gui);
 
+#ifdef HAVE_NBTK
+  action_area = gtk_dialog_get_action_area (GTK_DIALOG (priv->window));
+  gtk_widget_hide (action_area);
+
+  /* Translators: this is used only when built on a moblin platform */
+  gtk_button_set_label (GTK_BUTTON (priv->button_create), _("_Next"));
+  gtk_button_set_use_underline (GTK_BUTTON (priv->button_create), TRUE);
+#endif
+
   priv->combobox_protocol = empathy_protocol_chooser_new ();
   gtk_box_pack_start (GTK_BOX (priv->hbox_type),
       priv->combobox_protocol,
@@ -1616,6 +1713,9 @@ do_dispose (GObject *obj)
   g_signal_handlers_disconnect_by_func (priv->account_manager,
       accounts_dialog_connection_changed_cb,
       dialog);
+  g_signal_handlers_disconnect_by_func (priv->account_manager,
+      accounts_dialog_manager_ready_cb,
+      dialog);
 
   if (priv->connecting_id)
     g_source_remove (priv->connecting_id);
@@ -1705,50 +1805,19 @@ do_constructed (GObject *object)
 {
   EmpathyAccountsDialog *dialog = EMPATHY_ACCOUNTS_DIALOG (object);
   EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
-  GList *accounts, *l;
   gboolean import_asked;
 
   accounts_dialog_build_ui (dialog);
+  accounts_dialog_model_setup (dialog);
 
   /* Set up signalling */
   priv->account_manager = empathy_account_manager_dup_singleton ();
 
-  g_signal_connect (priv->account_manager, "account-created",
-      G_CALLBACK (accounts_dialog_account_added_cb),
-      dialog);
-  g_signal_connect (priv->account_manager, "account-deleted",
-      G_CALLBACK (accounts_dialog_account_removed_cb),
-      dialog);
-  g_signal_connect (priv->account_manager, "account-enabled",
-      G_CALLBACK (accounts_dialog_account_enabled_cb),
-      dialog);
-  g_signal_connect (priv->account_manager, "account-disabled",
-      G_CALLBACK (accounts_dialog_account_disabled_cb),
-      dialog);
-  g_signal_connect (priv->account_manager, "account-changed",
-      G_CALLBACK (accounts_dialog_account_changed_cb),
-      dialog);
-  g_signal_connect (priv->account_manager, "account-connection-changed",
-      G_CALLBACK (accounts_dialog_connection_changed_cb),
-      dialog);
-
-  accounts_dialog_model_setup (dialog);
-
-  /* Add existing accounts */
-  accounts = empathy_account_manager_dup_accounts (priv->account_manager);
-  for (l = accounts; l; l = l->next)
-    {
-      accounts_dialog_add_account (dialog, l->data);
-      g_object_unref (l->data);
-    }
-  g_list_free (accounts);
-
-  priv->cms = empathy_connection_managers_dup_singleton ();
-  if (!empathy_connection_managers_is_ready (priv->cms))
-    g_signal_connect (priv->cms, "notify::ready",
-        G_CALLBACK (accounts_dialog_cms_ready_cb), dialog);
-
-  accounts_dialog_model_select_first (dialog);
+  if (!empathy_account_manager_is_ready (priv->account_manager))
+    g_signal_connect (priv->account_manager, "notify::ready",
+        G_CALLBACK (accounts_dialog_manager_ready_cb), dialog);
+  else
+    accounts_dialog_accounts_setup (dialog);
 
   empathy_conf_get_bool (empathy_conf_get (),
       EMPATHY_PREFS_IMPORT_ASKED, &import_asked);
